@@ -24,7 +24,6 @@
 #include "config.h"
 #include <stdlib.h>
 #include <string.h>
-#include "gdk-pixbuf-private.h"
 #include "gdk-pixbuf-loader.h"
 #include "io-ani-animation.h"
 
@@ -162,10 +161,9 @@ prepared_callback (GdkPixbufLoader *loader,
 
 	if (context->pos == 0) 
 	{
-		if (context->prepared_func)
-			(* context->prepared_func) (pixbuf, 
-						    GDK_PIXBUF_ANIMATION (context->animation), 
-						    context->user_data);
+		(* context->prepared_func) (pixbuf, 
+					    GDK_PIXBUF_ANIMATION (context->animation), 
+					    context->user_data);
 	}
 	else {
 		/* FIXME - this is necessary for nice display of loading 
@@ -190,10 +188,9 @@ updated_callback (GdkPixbufLoader* loader,
 
 	GdkPixbuf *pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
 	
-	if (context->updated_func)
-		(* context->updated_func) (pixbuf, 
-					   x, y, width, height,
-					   context->user_data);
+	(* context->updated_func) (pixbuf, 
+				   x, y, width, height,
+				   context->user_data);
 }
 
 static gboolean
@@ -298,6 +295,23 @@ ani_load_chunk (AniLoaderContext *context, GError **error)
         
         if (context->chunk_id == TAG_anih) 
 	{
+		if (context->chunk_size < 36)
+		{
+			g_set_error_literal (error,
+                                             GDK_PIXBUF_ERROR,
+                                             GDK_PIXBUF_ERROR_CORRUPT_IMAGE,
+                                             _("Malformed chunk in animation"));
+			return FALSE;
+		}
+		if (context->animation)
+		{
+			g_set_error_literal (error,
+                                             GDK_PIXBUF_ERROR,
+                                             GDK_PIXBUF_ERROR_CORRUPT_IMAGE,
+                                             _("Invalid header in animation"));
+			return FALSE;
+		}
+
 		context->HeaderSize = read_int32 (context);
 		context->NumFrames = read_int32 (context);
 		context->NumSteps = read_int32 (context);
@@ -439,7 +453,7 @@ ani_load_chunk (AniLoaderContext *context, GError **error)
 	}
         else if (context->chunk_id == TAG_INAM) 
 	{
-		if (!context->animation) 
+		if (!context->animation || context->title)
 		{
 			g_set_error_literal (error,
                                              GDK_PIXBUF_ERROR,
@@ -466,7 +480,7 @@ ani_load_chunk (AniLoaderContext *context, GError **error)
 	}
         else if (context->chunk_id == TAG_IART) 
 	{
-		if (!context->animation) 
+		if (!context->animation || context->author)
 		{
 			g_set_error_literal (error,
                                              GDK_PIXBUF_ERROR,
@@ -587,6 +601,10 @@ gdk_pixbuf__ani_image_begin_load (GdkPixbufModuleSizeFunc size_func,
 {
         AniLoaderContext *context;
         
+	g_assert (size_func != NULL);
+	g_assert (prepared_func != NULL);
+	g_assert (updated_func != NULL);
+
         context = g_new0 (AniLoaderContext, 1);
         
         context->prepared_func = prepared_func;
