@@ -280,6 +280,11 @@ gdk_pixbuf_glycin_animation_iter_get_pixbuf (GdkPixbufAnimationIter *iter)
 static gboolean
 gdk_pixbuf_glycin_animation_iter_on_currently_loading_frame (G_GNUC_UNUSED GdkPixbufAnimationIter *iter)
 {
+  GdkPixbufGlycinAnimationIter *self = (GdkPixbufGlycinAnimationIter *) iter;
+
+  if (g_array_index (self->animation->decoded, GdkPixbufGlycinFrame, self->idx).is_last_frame)
+    return TRUE;
+
   return FALSE;
 }
 
@@ -293,7 +298,7 @@ gdk_pixbuf_glycin_animation_iter_advance (GdkPixbufAnimationIter *iter,
 
   new_time = timeval_to_usec (current_time);
 
-  while ((self->time + g_array_index (self->animation->decoded, GdkPixbufGlycinFrame, self->idx).delay) < new_time)
+  while ((self->time + g_array_index (self->animation->decoded, GdkPixbufGlycinFrame, self->idx).delay) <= new_time)
     {
       self->time += g_array_index (self->animation->decoded, GdkPixbufGlycinFrame, self->idx).delay;
 
@@ -501,8 +506,9 @@ done:
     }
   else if (g_error_matches (local_error, GLY_LOADER_ERROR, GLY_LOADER_ERROR_UNKNOWN_IMAGE_FORMAT))
     {
+      /* glycins message for this error is excessive */
       g_set_error_literal (error, GDK_PIXBUF_ERROR, GDK_PIXBUF_ERROR_UNKNOWN_TYPE,
-                           local_error->message);
+                           "Unsupported image format");
       g_clear_error (&local_error);
     }
   else if (local_error)
